@@ -1159,7 +1159,6 @@ static int init_sl_gtk(SLang_NameSpace_Type *ns)
    return 0;
 }
 
-
 SLANG_MODULE(gtk);
 int init_gtk_module_ns(char *ns_name)
 {
@@ -1185,6 +1184,9 @@ int init_gtk_module_ns(char *ns_name)
 
    if (!GtkOpaque_Type) {			/* Already initialized */
 
+	/* Support lite module testing w/out connecting to display system */
+	int needs_display = getenv("SLGTK_NO_DISPLAY") == NULL;
+
 	if (allocate_reserved_opaque_types() == -1 ||
 	 				allocate_gtk_opaque_types() == -1)
 	   return -1;
@@ -1192,7 +1194,7 @@ int init_gtk_module_ns(char *ns_name)
 	/* FIXME: is this still necessary? */
 	putenv("GTK_IM_MODULE_FILE=/dev/null");
 
-	if (gtk_init_check(&argc,&argv) != TRUE) {
+	if (gtk_init_check(&argc,&argv) != TRUE && needs_display) {
 	   SLang_verror(SLEI, "could not initialize Gtk (check $DISPLAY, etc)");
 	   return -1; 
 	}
